"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rest = require("rest");
const AuthenticationInterceptor_1 = require("./AuthenticationInterceptor");
const errorCode = require("rest/interceptor/errorCode");
class Authentication {
    constructor() {
        this.authInterceptor = new AuthenticationInterceptor_1.AuthInterceptor().get();
    }
    /**
     * Signin takes all necessary parameters to handle authentication.
     * The endpoint will be the one assigned to the company by Responsis,
     * likely one of https://login[2,5].responsys.net/rest/api/v1.3/auth/token
     *
     * Will eventually return an object with the following information:
     * {
     *   "authToken" : <AUTH_TOKEN>,
     *   "issuedAt" :  <TIMESTAMP> ,
     *   "endPoint" : <ENDPOINT_URI>
     * }
     * The authToken must be used for future requests to the API using the endPoint
     * URL provided. This token expires after at most 2 hours.
     *
     * @param authRequest Encapsulates username, password and endpoint.
     */
    signin(authRequest) {
        const client = rest.wrap(this.authInterceptor);
        return client(authRequest);
    }
    /**
     * Refreshes the token by passing a previously valid token.
     * Tokens expire every 2 hours.
     * Will eventually return the same values as @method signin
     * @param authRefresh Encapsulates token and endpoint.
     */
    refresh(authRefresh) {
        const client = rest
            .wrap(errorCode)
            .wrap(this.authInterceptor);
        return client(authRefresh);
    }
}
exports.Authentication = Authentication;
//# sourceMappingURL=Authentication.js.map