"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const interceptor = require("rest/interceptor");
const AuthCache_1 = require("./AuthCache");
const Authentication_1 = require("./Authentication");
const AuthenticationRequest_1 = require("./AuthenticationRequest");
class SecureClientInterceptor {
    constructor() {
        this.authCache = new AuthCache_1.AuthCache();
        this.authentication = new Authentication_1.Authentication();
    }
    get() {
        return interceptor({
            request: async (request) => {
                if (!this.authCache.isLoaded()) {
                    await this.authentication.signin(new AuthenticationRequest_1.AuthenticationRequest());
                    request.headers.Authorization = this.authCache.getToken();
                    return request;
                }
                return request;
            },
            success: async (response, _, meta) => {
                const status = response.status || { code: 408 };
                if (status.code === 401 || status.code === 403) {
                    const request = response.request;
                    await this.authentication.signin(new AuthenticationRequest_1.AuthenticationRequest());
                    request.headers.Authorization = this.authCache.getToken();
                    return meta.client(request);
                }
                return response;
            },
            error: response => response
        });
    }
}
exports.SecureClientInterceptor = SecureClientInterceptor;
//# sourceMappingURL=SecureClientInterceptor.js.map