"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const config = require("config");
const AuthCache_1 = require("../AuthCache");
const DEFAULT = {
    authToken: config.get('refresh.authToken'),
    issuedAt: config.get('refresh.issuedAt'),
    endPoint: config.get('refresh.endPoint')
};
const TEST = {
    authToken: 'auth-token',
    issuedAt: 1234567890,
    endPoint: 'endpoint'
};
describe('AuthCache', () => {
    const authCache = new AuthCache_1.AuthCache();
    beforeEach(() => {
        authCache.clear();
        authCache.set(DEFAULT);
    });
    it('should set an authentication response', () => {
        authCache.set(TEST);
        chai_1.expect(authCache.getToken()).to.equal(TEST.authToken);
        chai_1.expect(authCache.getEndpoint()).to.equal(TEST.endPoint);
        chai_1.expect(authCache.getIssued()).to.equal(TEST.issuedAt);
    });
    it('should restore an authentication response from cache', () => {
        const token = authCache.getToken();
        chai_1.expect(token).to.equal(DEFAULT.authToken);
    });
    it('should restore a previously persisted endpoint', () => {
        const endpoint = authCache.getEndpoint();
        chai_1.expect(endpoint).to.equal(DEFAULT.endPoint);
    });
    it('should restore a previously persisted issued date', () => {
        const issued = authCache.getIssued();
        chai_1.expect(issued).to.equal(DEFAULT.issuedAt);
    });
    it('should remove all values from authentication cache', () => {
        authCache.clear();
        chai_1.expect(authCache.getToken()).to.be.undefined;
        chai_1.expect(authCache.getEndpoint()).to.be.undefined;
        chai_1.expect(authCache.getIssued()).to.be.undefined;
    });
    it('should return true or false if cache is loaded', () => {
        chai_1.expect(authCache.isLoaded()).to.be.true;
        authCache.clear();
        chai_1.expect(authCache.isLoaded()).to.be.false;
    });
});
//# sourceMappingURL=AuthCache.test.js.map