"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config = require("config");
const AuthConfig_1 = require("../AuthConfig");
const chai_1 = require("chai");
const fs = require("fs");
const PATH_TEST = `${__dirname}/../../../config/test.json`;
describe('AuthConfig', () => {
    afterEach(() => {
        process.env.NODE_ENV = 'test';
        AuthConfig_1.AuthConfig.init();
    });
    it('should contain username, password and endpoint attributes', () => {
        AuthConfig_1.AuthConfig.init();
        chai_1.expect(AuthConfig_1.AuthConfig).to.have.property('username');
        chai_1.expect(AuthConfig_1.AuthConfig).to.have.property('password');
        chai_1.expect(AuthConfig_1.AuthConfig).to.have.property('endpoint');
    });
    it('should get authentication settings from config file when testing', () => {
        const username = AuthConfig_1.AuthConfig.username;
        const password = AuthConfig_1.AuthConfig.password;
        const endpoint = AuthConfig_1.AuthConfig.endpoint;
        const testConfig = JSON.parse(fs.readFileSync(PATH_TEST, 'utf8'));
        chai_1.expect(username).to.equal(testConfig.auth.username);
        chai_1.expect(password).to.equal(testConfig.auth.password);
        chai_1.expect(endpoint).to.equal(testConfig.auth.endPoint);
    });
    it('should get authentication settings from envvars in production', () => {
        const PRODUCTION = 'production';
        process.env.NODE_ENV = PRODUCTION;
        AuthConfig_1.AuthConfig.init();
        chai_1.expect(process.env.NODE_ENV).to.equal(PRODUCTION);
        chai_1.expect(AuthConfig_1.AuthConfig.endpoint).to.equal(config.get('auth.endPoint'));
        chai_1.expect(AuthConfig_1.AuthConfig.username).to.equal(config.get('auth.username'));
        chai_1.expect(AuthConfig_1.AuthConfig.password).to.equal(config.get('auth.password'));
    });
    it('should allow to override configuration with params in production', () => {
        const endpoint = 'test-endpoint';
        const username = 'test-username';
        const password = 'test-password';
        delete process.env.NODE_ENV;
        AuthConfig_1.AuthConfig.init(endpoint, username, password);
        chai_1.expect(AuthConfig_1.AuthConfig.endpoint).to.equal(endpoint);
        chai_1.expect(AuthConfig_1.AuthConfig.username).to.equal(username);
        chai_1.expect(AuthConfig_1.AuthConfig.password).to.equal(password);
    });
});
//# sourceMappingURL=AuthConfig.test.js.map