"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const config = require("config");
const AuthCache_1 = require("../AuthCache");
const PathInterceptor_1 = require("../PathInterceptor");
const rest = require("rest");
describe('PathInterceptor', () => {
    const AUTH_DATA = {
        authToken: 'TEST',
        issuedAt: config.get('refresh.issuedAt'),
        endPoint: 'http://test_endpoint'
    };
    const PATH = '/test_path';
    const COMPLETE_PATH = AUTH_DATA.endPoint + PATH;
    const interceptor = new PathInterceptor_1.PathInterceptor().get();
    const client = rest.wrap(interceptor);
    const authCache = new AuthCache_1.AuthCache();
    before(() => {
        authCache.clear();
    });
    afterEach(() => {
        authCache.clear();
    });
    it('should add the path from AuthConfig when missing', (done) => {
        authCache.set(AUTH_DATA);
        chai_1.expect(authCache.getEndpoint()).to.equal(AUTH_DATA.endPoint);
        client(PATH).then(() => {
            chai_1.expect.fail('Should fail because no server is up');
        }).catch((error) => {
            chai_1.expect(error.request.path).to.equal(COMPLETE_PATH);
            done();
        });
    });
    it('should leave unchanged when endpoint already contained in path', (done) => {
        authCache.set(AUTH_DATA);
        chai_1.expect(authCache.getEndpoint()).to.equal(AUTH_DATA.endPoint);
        client(COMPLETE_PATH).then(() => {
            chai_1.expect.fail('Should fail because no server is up');
        }).catch((error) => {
            chai_1.expect(error.request.path).to.equal(COMPLETE_PATH);
            done();
        });
    });
    it('should throw an error if authentication not loaded.', (done) => {
        chai_1.expect(authCache.isLoaded()).to.be.false;
        client(PATH).then(() => {
            chai_1.expect.fail('Should fail because no server is up');
        }).catch((error) => {
            chai_1.expect(error.error).to.equal('Authentication Missing: Cannot add endpoint to path.');
            done();
        });
    });
});
//# sourceMappingURL=PathInterceptor.test.js.map