"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rest = require("rest");
const SecureClientInterceptor_1 = require("../auth/SecureClientInterceptor");
const retry = require("rest/interceptor/retry");
const errorCode = require("rest/interceptor/errorCode");
const timeout = require("rest/interceptor/timeout");
const Options_1 = require("./Options");
const PathInterceptor_1 = require("../auth/PathInterceptor");
class Client {
    constructor(options) {
        this.secureInterceptor = new SecureClientInterceptor_1.SecureClientInterceptor().get();
        this.pathInterceptor = new PathInterceptor_1.PathInterceptor().get();
        this.options = options || new Options_1.Options();
    }
    /**
     * Wraps http client with all necessary interceptors. Interceptor order is important.
     *
     * errorCode catches status other than 200 to be treated as errors.
     * retry executes requests again until timeout.
     * secureClientInterceptor handles authentication to responsys.
     * timeout canceles a request after the time set.
     * @param request
     */
    call(request) {
        const client = rest
            .wrap(errorCode, this.options.errorOptions)
            .wrap(retry, this.options.retryOptions)
            .wrap(timeout, this.options.timeoutOptions)
            .wrap(this.pathInterceptor)
            .wrap(this.secureInterceptor);
        return client(request);
    }
}
exports.Client = Client;
//# sourceMappingURL=Client.js.map