"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const express = require("express");
const config = require("config");
const Client_1 = require("../Client");
const Options_1 = require("../Options");
const Request_1 = require("../Request");
const chai_1 = require("chai");
const AuthCache_1 = require("../../auth/AuthCache");
const TEST_URL = 'http://127.0.0.1:3000';
const TEST_RESULT = 'result_ok';
const TEST_HEADER = {
    'content-type': 'application/json'
};
const RESPONSE = {
    authToken: config.get('refresh.authToken'),
    issuedAt: 1510880256844,
    endPoint: 'http://127.0.0.1:3000'
};
let request;
let server;
let errorCount;
function startServer(fails) {
    const app = express();
    app.get('/', (_, res) => {
        if (errorCount >= fails) {
            errorCount = 0;
            return res.send(TEST_RESULT);
        }
        errorCount += 1;
        return res.status(500).send('error');
    });
    return app.listen(3000, () => { });
}
class TestClient extends Client_1.Client {
    constructor(options) {
        super(options);
    }
    call(request) {
        return super.call(request);
    }
}
describe('Client', () => {
    const authCache = new AuthCache_1.AuthCache();
    after(() => {
        authCache.clear();
    });
    beforeEach(() => {
        authCache.clear();
        authCache.set(RESPONSE);
        errorCount = 0;
        request = new Request_1.Request('', TEST_URL, TEST_HEADER, 'GET');
    });
    afterEach((done) => {
        server.close(done);
    });
    it('should retry requests when failed', (done) => {
        server = startServer(2);
        const client = new TestClient();
        client.call(request).then((result) => {
            chai_1.expect(result.status.code).to.equal(200);
            chai_1.expect(result.entity).to.equal(TEST_RESULT);
            done();
        });
    });
    it('should stop retrying requests after timeout', (done) => {
        server = startServer(10);
        const requestOptions = new Options_1.Options();
        requestOptions.timeoutOptions.timeout = 100;
        const client = new TestClient(requestOptions);
        client.call(request).then((result) => {
            chai_1.expect(result.error).to.equal('timeout');
            chai_1.expect(result.request.canceled).to.be.true;
            done();
        });
    });
});
//# sourceMappingURL=Client.test.js.map