"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const nock_utils_1 = require("nock-utils");
const AuthCache_1 = require("../../auth/AuthCache");
const MergeRequest_1 = require("../merge/MergeRequest");
const MergeMessage_1 = require("../merge/MergeMessage");
const MergeData_1 = require("../../table/merge/MergeData");
const LIST_NAME = 'api_list_example';
const CASSETTE_PATH = `${__dirname}/cassettes/mergeList.json`;
const currentDate = '2019-03-22T11:54:40.531Z';
const recorder = new nock_utils_1.HttpRecorder(CASSETTE_PATH);
describe('Merge List', () => {
    const authCache = new AuthCache_1.AuthCache();
    before(() => {
        authCache.clear();
        recorder.start();
    });
    after(() => {
        authCache.clear();
        recorder.stop();
    });
    it('should merge a table', async () => {
        const fieldNames = ['EMAIL_ADDRESS_', 'BIRTHDATE'];
        const records = new Set();
        const record1 = ['prueba@comparaonline.com', currentDate];
        const record2 = ['prueba2@comparaonline.com', currentDate];
        records.add(record1);
        records.add(record2);
        const mergeData = new MergeData_1.MergeData(fieldNames, records);
        const message = new MergeRequest_1.ListMergeRequest(mergeData, LIST_NAME);
        const trigger = new MergeMessage_1.ListMergeMessage();
        const result = await trigger.send(message);
        chai_1.expect(result.status.code).to.equal(200);
    });
    it('merge table with matchColumn', async () => {
        const fieldNames = ['EMAIL_ADDRESS_', 'BIRTHDATE'];
        const records = new Set();
        const matchColumn = 'EMAIL_ADDRESS_';
        const record1 = ['prueba@comparaonline.com', currentDate];
        records.add(record1);
        const mergeData = new MergeData_1.MergeData(fieldNames, records);
        const message = new MergeRequest_1.ListMergeRequest(mergeData, LIST_NAME, matchColumn);
        const trigger = new MergeMessage_1.ListMergeMessage();
        const result = await trigger.send(message);
        chai_1.expect(result.status.code).to.equal(200);
    });
});
//# sourceMappingURL=merge.test.js.map