"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config = require("config");
const chai_1 = require("chai");
const MergeEmail_1 = require("../MergeEmail");
const MergeTriggerRecordData_1 = require("../MergeTriggerRecordData");
const MergeTriggerEmailRequest_1 = require("../MergeTriggerEmailRequest");
const queryString = require("querystring");
const MergeTriggerEmailRecordData_1 = require("../MergeTriggerEmailRecordData");
const AuthCache_1 = require("../../auth/AuthCache");
const nock_utils_1 = require("nock-utils");
const OptionalData_1 = require("../../send/OptionalData");
const Constants_1 = require("../../Constants");
const CAMPAIGN = config.get('campaign');
const CASSETTE_PATH = `${__dirname}/cassettes/mergeEmailCassette.json`;
const recorder = new nock_utils_1.HttpRecorder(CASSETTE_PATH);
describe('MergeEmail', () => {
    const authCache = new AuthCache_1.AuthCache();
    before(() => {
        authCache.clear();
        recorder.start();
    });
    after(() => {
        authCache.clear();
        recorder.stop();
    });
    it('should add an email to campaign', async () => {
        const recordDatas = new Set();
        const fieldValues = ['suarezcumare@gmail.com', 'suarezcumare'];
        const optionalData1 = new OptionalData_1.OptionalData('FIRST_NAME', 'Alexander');
        const optionalData2 = new OptionalData_1.OptionalData('LAST_NAME', 'Cumare');
        const optionalData = new Set();
        optionalData.add(optionalData1);
        optionalData.add(optionalData2);
        const data = new MergeTriggerEmailRecordData_1.MergeTriggerEmailRecordData(fieldValues, optionalData);
        recordDatas.add(data);
        const mergeTriggerRecordData = new MergeTriggerRecordData_1.MergeTriggerRecordData(recordDatas);
        const campaign = queryString.escape(CAMPAIGN);
        const emails = new MergeTriggerEmailRequest_1.MergeTriggerEmailRequest(mergeTriggerRecordData, campaign);
        const merge = new MergeEmail_1.MergeEmail();
        const result = await merge.send(emails);
        const resultArray = JSON.parse(result.entity);
        chai_1.expect(result.status.code).to.equal(200);
        resultArray.forEach((element) => {
            chai_1.expect(element.errorMessage).to.be.null;
            chai_1.expect(element.success).to.be.true;
            chai_1.expect(element.recipientId).to.be.gt(0);
        });
    });
    it('should return error for a invalid email address', async () => {
        const recordDatas = new Set();
        const fieldValues = ['email@.com', 'email'];
        const optionalData1 = new OptionalData_1.OptionalData('FIST_NAME', 'first');
        const optionalData2 = new OptionalData_1.OptionalData('LAST_NAME', 'name');
        const optionalData = new Set();
        optionalData.add(optionalData1);
        optionalData.add(optionalData2);
        const data = new MergeTriggerEmailRecordData_1.MergeTriggerEmailRecordData(fieldValues, optionalData);
        recordDatas.add(data);
        const mergeTriggerRecordData = new MergeTriggerRecordData_1.MergeTriggerRecordData(recordDatas);
        const campaign = queryString.escape(CAMPAIGN);
        const emails = new MergeTriggerEmailRequest_1.MergeTriggerEmailRequest(mergeTriggerRecordData, campaign);
        const merge = new MergeEmail_1.MergeEmail();
        const result = await merge.send(emails);
        const resultArray = JSON.parse(result.entity);
        chai_1.expect(resultArray.errorCode).to.contain(Constants_1.INVALID_PARAMETER);
        chai_1.expect(resultArray.title).to.contain(Constants_1.INVALID_REQUEST_PARAMETERS);
    });
});
//# sourceMappingURL=MergeEmail.test.js.map