"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const Recipient_1 = require("../Recipient");
const queryString = require("querystring");
const RecipientData_1 = require("../RecipientData");
const AuthCache_1 = require("../../auth/AuthCache");
const nock_utils_1 = require("nock-utils");
const OptionalData_1 = require("../OptionalData");
const ListName_1 = require("../ListName");
const TriggerEventMessageRequest_1 = require("../TriggerEventMessageRequest");
const TriggerEventMessage_1 = require("../TriggerEventMessage");
const CASSETTE_PATH = `${__dirname}/cassettes/triggerEventMessageCassette.json`;
const recorder = new nock_utils_1.HttpRecorder(CASSETTE_PATH);
describe('TriggerEventMessage', () => {
    const EVENT_NAME = 'test';
    const authCache = new AuthCache_1.AuthCache();
    before(() => {
        authCache.clear();
        recorder.start();
    });
    after(() => {
        authCache.clear();
        recorder.stop();
    });
    it('should not send an email with list name', async () => {
        const recipients = new Set();
        const recipient1 = new Recipient_1.Recipient();
        recipient1.emailAddress = 'tsuarez@comparaonline.com';
        recipient1.emailFormat = 'HTML_FORMAT';
        recipient1.mobileNumber = '951349394';
        const optionalData1 = new OptionalData_1.OptionalData('FIST_NAME', 'name');
        const optionalData2 = new OptionalData_1.OptionalData('LAST_NAME', 'last name');
        const optionalData = new Set();
        optionalData.add(optionalData1);
        optionalData.add(optionalData2);
        const data = new RecipientData_1.RecipientData(recipient1, optionalData);
        recipients.add(data);
        const eventName = queryString.escape(EVENT_NAME);
        const message = new TriggerEventMessageRequest_1.TriggerEventMessageRequest(recipients, {
            eventNumberDataMapping: '',
            eventDateDataMapping: '',
            eventStringDataMapping: ''
        }, eventName);
        const trigger = new TriggerEventMessage_1.TriggerEventMessage();
        const result = await trigger.send(message);
        const resultArray = JSON.parse(result.entity);
        chai_1.expect(result.status.code).to.equal(200);
        resultArray.forEach((element) => {
            chai_1.expect(element.success).to.be.false;
            chai_1.expect(element.recipientId).to.eql(-1);
        });
    });
    it('should send an email with listName', async () => {
        const recipients = new Set();
        const recipient1 = new Recipient_1.Recipient();
        recipient1.emailAddress = 'tsuarez@comparaonline.com';
        recipient1.emailFormat = 'HTML_FORMAT';
        recipient1.mobileNumber = '951349394';
        const listName = new ListName_1.ListName();
        listName.objectName = 'CONTACTS_LIST';
        listName.folderName = 'CONTACTS_LIST';
        recipient1.listName = listName;
        const optionalData1 = new OptionalData_1.OptionalData('FIST_NAME', 'name');
        const optionalData2 = new OptionalData_1.OptionalData('LAST_NAME', 'last name');
        const optionalData = new Set();
        optionalData.add(optionalData1);
        optionalData.add(optionalData2);
        const data = new RecipientData_1.RecipientData(recipient1, optionalData);
        recipients.add(data);
        const eventName = queryString.escape(EVENT_NAME);
        const message = new TriggerEventMessageRequest_1.TriggerEventMessageRequest(recipients, {
            eventNumberDataMapping: '',
            eventDateDataMapping: '',
            eventStringDataMapping: ''
        }, eventName);
        const trigger = new TriggerEventMessage_1.TriggerEventMessage();
        const result = await trigger.send(message);
        const resultArray = JSON.parse(result.entity);
        chai_1.expect(result.status.code).to.equal(200);
        resultArray.forEach((element) => {
            chai_1.expect(element.errorMessage).to.be.null;
            chai_1.expect(element.success).to.be.true;
            chai_1.expect(element.recipientId).to.be.gt(0);
        });
    });
});
//# sourceMappingURL=TriggerEventMessage.test.js.map