"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const nock_utils_1 = require("nock-utils");
const queryString = require("querystring");
const AuthCache_1 = require("../../auth/AuthCache");
const FieldTypes_1 = require("../create/FieldTypes");
const TableData_1 = require("../create/TableData");
const CreateRequest_1 = require("../create/CreateRequest");
const CreateMessage_1 = require("../create/CreateMessage");
const TABLE_NAME_VALID = 'test_api_responsys';
const TABLE_NAME_INVALID = 'test_api_responsys';
const FOLDER_NAME = queryString.escape('test_api');
const CASSETTE_PATH = `${__dirname}/cassettes/createTable.json`;
const recorder = new nock_utils_1.HttpRecorder(CASSETTE_PATH);
describe('Create Table', () => {
    const authCache = new AuthCache_1.AuthCache();
    before(() => {
        authCache.clear();
        recorder.start();
    });
    after(() => {
        authCache.clear();
        recorder.stop();
    });
    it('should create a table', async () => {
        const fields = new Set();
        const primaryKeys = ['offerId'];
        const idFeld = new FieldTypes_1.Field();
        idFeld.fieldName = 'offerId';
        idFeld.fieldType = 'INTEGER';
        idFeld.dataExtractionKey = false;
        fields.add(idFeld);
        const nameField = new FieldTypes_1.Field();
        nameField.fieldName = 'offerName';
        nameField.fieldType = 'STR100';
        nameField.dataExtractionKey = false;
        fields.add(nameField);
        const emailField = new FieldTypes_1.Field();
        emailField.fieldName = 'offerEmail';
        emailField.fieldType = 'STR500';
        emailField.dataExtractionKey = false;
        fields.add(emailField);
        const dateField = new FieldTypes_1.Field();
        dateField.fieldName = 'offerDate';
        dateField.fieldType = 'TIMESTAMP';
        dateField.dataExtractionKey = false;
        fields.add(dateField);
        const table = new TableData_1.TableData(TABLE_NAME_VALID, fields, primaryKeys);
        const message = new CreateRequest_1.TableCreateRequest(table, FOLDER_NAME);
        const trigger = new CreateMessage_1.TableCreateMessage();
        const result = await trigger.send(message);
        chai_1.expect(result.status.code).to.equal(200);
    });
    it('should not create a table because the primaryKeys', async () => {
        const fields = new Set();
        const primaryKeys = ['otherPrimary'];
        const idFeld = new FieldTypes_1.Field();
        idFeld.fieldName = 'offerId';
        idFeld.fieldType = 'INTEGER';
        idFeld.dataExtractionKey = false;
        fields.add(idFeld);
        const nameField = new FieldTypes_1.Field();
        nameField.fieldName = 'offerName';
        nameField.fieldType = 'STR100';
        nameField.dataExtractionKey = false;
        fields.add(nameField);
        const emailField = new FieldTypes_1.Field();
        emailField.fieldName = 'offerEmail';
        emailField.fieldType = 'STR5000';
        emailField.dataExtractionKey = false;
        fields.add(emailField);
        const dateField = new FieldTypes_1.Field();
        dateField.fieldName = 'offerDate';
        dateField.fieldType = 'TIMESTAMP';
        dateField.dataExtractionKey = false;
        fields.add(dateField);
        const table = new TableData_1.TableData(TABLE_NAME_INVALID, fields, primaryKeys);
        const message = new CreateRequest_1.TableCreateRequest(table, FOLDER_NAME);
        const trigger = new CreateMessage_1.TableCreateMessage();
        const result = await trigger.send(message);
        const resultResponse = JSON.parse(result.entity);
        chai_1.expect(result.status.code).to.equal(400);
        chai_1.expect(resultResponse.errorCode).to.not.null;
        chai_1.expect(resultResponse.detail).to.not.null;
    });
});
//# sourceMappingURL=create.test.js.map