"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const nock_utils_1 = require("nock-utils");
const queryString = require("querystring");
const AuthCache_1 = require("../../auth/AuthCache");
const MergeData_1 = require("../merge/MergeData");
const MergeRequest_1 = require("../merge/MergeRequest");
const MergeMessage_1 = require("../merge/MergeMessage");
const TABLE_NAME = 'test_api_responsys';
const FOLDER_NAME = queryString.escape('test_api');
const CASSETTE_PATH = `${__dirname}/cassettes/mergeTable.json`;
const currentDate = '2019-03-22T11:54:40.531Z';
const recorder = new nock_utils_1.HttpRecorder(CASSETTE_PATH);
describe('Merge Table', () => {
    const authCache = new AuthCache_1.AuthCache();
    before(() => {
        authCache.clear();
        recorder.start();
    });
    after(() => {
        authCache.clear();
        recorder.stop();
    });
    it('should merge a table', async () => {
        const fieldNames = ['offerId', 'offerName', 'offerEmail', 'offerDate'];
        const records = new Set();
        const record1 = ['1', 'test3', 'prueba@comparaonline.com', currentDate];
        const record2 = ['2', 'test4', 'prueba2@comparaonline.com', currentDate];
        records.add(record1);
        records.add(record2);
        const mergeData = new MergeData_1.MergeData(fieldNames, records);
        const message = new MergeRequest_1.TableMergeRequest(mergeData, FOLDER_NAME, TABLE_NAME);
        const trigger = new MergeMessage_1.TableMergeMessage();
        const result = await trigger.send(message);
        chai_1.expect(result.status.code).to.equal(200);
    });
    it('should not merge a table', async () => {
        const fieldNames = ['offerId', 'offerName', 'offerEmail', 'offerDate'];
        const records = new Set();
        const record1 = ['1w', 'test1', 'prueba@comparaonline.com', currentDate];
        records.add(record1);
        const mergeData = new MergeData_1.MergeData(fieldNames, records);
        const message = new MergeRequest_1.TableMergeRequest(mergeData, FOLDER_NAME, TABLE_NAME);
        const trigger = new MergeMessage_1.TableMergeMessage();
        const result = await trigger.send(message);
        const resultResponse = JSON.parse(result.entity);
        chai_1.expect(result.status.code).to.equal(200);
        resultResponse.recordData.records.some((element) => {
            chai_1.expect(element).to.not.equal('');
        });
    });
    it('should not merge a table with PK and marchColumnNames', async () => {
        const fieldNames = ['offerId', 'offerName', 'offerEmail', 'offerDate'];
        const records = new Set();
        const record1 = ['1', 'test1', 'prueba@comparaonline.com', currentDate];
        records.add(record1);
        const mergeData = new MergeData_1.MergeData(fieldNames, records);
        const message = new MergeRequest_1.TableMergeRequest(mergeData, FOLDER_NAME, TABLE_NAME, ['offerId']);
        const trigger = new MergeMessage_1.TableMergeMessage();
        const result = await trigger.send(message);
        const resultResponse = JSON.parse(result.entity);
        chai_1.expect(result.status.code).to.equal(400);
        chai_1.expect(resultResponse.errorCode).to.not.null;
        chai_1.expect(resultResponse.detail).to.not.null;
    });
});
//# sourceMappingURL=merge.test.js.map